@@ -163,10 +163,8 @@ test_bit(int nr, unsigned long addr)
 				&& (NUMBER(PG_hwpoison) != NOT_FOUND_NUMBER))
 #define isAnon(mapping, flags, _mapcount) \
 	(((unsigned long)mapping & PAGE_MAPPING_ANON) != 0 && !isSlab(flags, _mapcount))
-
-#define PAGE_TYPE_BASE		(0xf0000000)
-
-#define PAGE_TYPE_BASE		(0xf0000000)
+#define isUnaccepted(_mapcount)	(_mapcount == (int)NUMBER(PAGE_UNACCEPTED_MAPCOUNT_VALUE) \
+				&& (NUMBER(PAGE_UNACCEPTED_MAPCOUNT_VALUE) != NOT_FOUND_NUMBER))
 
 #define PTOB(X)			(((unsigned long long)(X)) << PAGESHIFT())
 #define BTOP(X)			(((unsigned long long)(X)) >> PAGESHIFT())
@@ -501,7 +499,7 @@ do { \
 #define KVER_MIN_SHIFT 16
 #define KERNEL_VERSION(x,y,z) (((x) << KVER_MAJ_SHIFT) | ((y) << KVER_MIN_SHIFT) | (z))
 #define OLDEST_VERSION		KERNEL_VERSION(2, 6, 15) /* linux-2.6.15 */
-#define LATEST_VERSION		KERNEL_VERSION(6, 11, 4) /* linux-6.11.4 */
+#define LATEST_VERSION		KERNEL_VERSION(6, 17, 4) /* linux-6.17.4 */
 
 /*
  * for printk caller_id support
@@ -2261,6 +2259,7 @@ struct number_table {
 	long	PAGE_HUGETLB_MAPCOUNT_VALUE;
 	long	PAGE_OFFLINE_MAPCOUNT_VALUE;
 	long	PAGE_SLAB_MAPCOUNT_VALUE;
+	long	PAGE_UNACCEPTED_MAPCOUNT_VALUE;
 	long	SECTION_SIZE_BITS;
 	long	MAX_PHYSMEM_BITS;
 	long    HUGETLB_PAGE_DTOR;
